mix lightpanda (lightpanda_ex v0.1.0)

Copy Markdown View Source

Invokes Lightpanda with the given args.

Usage:

$ mix lightpanda TASK_OPTIONS PROFILE LIGHTPANDA_ARGS

Example:

$ mix lightpanda default

If Lightpanda is not installed, it is automatically downloaded. Note the arguments given to this task will be appended to any configured arguments.

Options

  • --runtime-config - load the runtime configuration before executing command

Note flags to control this Mix task must be given before the profile:

$ mix lightpanda --runtime-config default